@@ -1,6 +1,6 @@
 package Beam::Wire;
 # ABSTRACT: Lightweight Dependency Injection Container
-$Beam::Wire::VERSION = '1.014';
+$Beam::Wire::VERSION = '1.015';
 use strict;
 use warnings;
 
@@ -528,7 +528,7 @@ sub validate {
 
 
 package Beam::Wire::Exception;
-$Beam::Wire::Exception::VERSION = '1.014';
+$Beam::Wire::Exception::VERSION = '1.015';
 use Moo;
 with 'Throwable';
 use Types::Standard qw( :all );
@@ -541,7 +541,7 @@ has error => (
 
 
 package Beam::Wire::Exception::Constructor;
-$Beam::Wire::Exception::Constructor::VERSION = '1.014';
+$Beam::Wire::Exception::Constructor::VERSION = '1.015';
 use Moo;
 use Types::Standard qw( :all );
 extends 'Beam::Wire::Exception';
@@ -554,7 +554,7 @@ has attr => (
 
 
 package Beam::Wire::Exception::Config;
-$Beam::Wire::Exception::Config::VERSION = '1.014';
+$Beam::Wire::Exception::Config::VERSION = '1.015';
 use Moo;
 use Types::Standard qw( :all );
 extends 'Beam::Wire::Exception';
@@ -582,7 +582,7 @@ has '+error' => (
 
 
 package Beam::Wire::Exception::Service;
-$Beam::Wire::Exception::Service::VERSION = '1.014';
+$Beam::Wire::Exception::Service::VERSION = '1.015';
 use Moo;
 use Types::Standard qw( :all );
 extends 'Beam::Wire::Exception';
@@ -600,7 +600,7 @@ has file => (
 
 
 package Beam::Wire::Exception::NotFound;
-$Beam::Wire::Exception::NotFound::VERSION = '1.014';
+$Beam::Wire::Exception::NotFound::VERSION = '1.015';
 use Moo;
 extends 'Beam::Wire::Exception::Service';
 
@@ -616,7 +616,7 @@ has '+error' => (
 
 
 package Beam::Wire::Exception::InvalidConfig;
-$Beam::Wire::Exception::InvalidConfig::VERSION = '1.014';
+$Beam::Wire::Exception::InvalidConfig::VERSION = '1.015';
 use Moo;
 extends 'Beam::Wire::Exception::Service';
 use overload q{""} => sub {
@@ -642,7 +642,7 @@ Beam::Wire - Lightweight Dependency Injection Container
 
 =head1 VERSION
 
-version 1.014
+version 1.015
 
 =head1 SYNOPSIS
 
@@ -1226,7 +1226,7 @@ Al Newkirk <anewkirk@ana.io>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Bruce Armstrong
+=for stopwords Bruce Armstrong Kent Fredric
 
 =over 4
 
@@ -1238,6 +1238,10 @@ Bruce Armstrong <bruce@armstronganchor.net>
 
 Bruce Armstrong <bruce@fortressofgeekdom.org>
 
+=item *
+
+Kent Fredric <kentnl@cpan.org>
+
 =back
 
 =head1 COPYRIGHT AND LICENSE
